diff --git a/.directory b/.directory
index d1d4fb1..55a324a 100644
--- a/.directory
+++ b/.directory
@@ -1,5 +1,5 @@
[Dolphin]
-Timestamp=2015,3,17,13,30,24
+Timestamp=2015,4,15,17,6,30
Version=3
ViewMode=1
diff --git a/sites/all/themes/gui/jee/assets/img/title-OPP-blur.png b/sites/all/themes/gui/jee/assets/img/title-OPP-blur.png
index 96a5d3a..296dd33 100644
Binary files a/sites/all/themes/gui/jee/assets/img/title-OPP-blur.png and b/sites/all/themes/gui/jee/assets/img/title-OPP-blur.png differ
diff --git a/sites/all/themes/gui/jee/assets/img/title-OPP-blur.svg b/sites/all/themes/gui/jee/assets/img/title-OPP-blur.svg
index ea0c6f7..5053eef 100644
--- a/sites/all/themes/gui/jee/assets/img/title-OPP-blur.svg
+++ b/sites/all/themes/gui/jee/assets/img/title-OPP-blur.svg
@@ -1688,9 +1688,9 @@
borderopacity="1.0"
inkscape:pageopacity="0.0"
inkscape:pageshadow="2"
- inkscape:zoom="3.959798"
- inkscape:cx="127.21373"
- inkscape:cy="21.421693"
+ inkscape:zoom="0.35"
+ inkscape:cx="42.739294"
+ inkscape:cy="46.690785"
inkscape:document-units="px"
inkscape:current-layer="layer1"
showgrid="false"
@@ -1708,7 +1708,7 @@
image/svg+xml
-
+
@@ -1718,289 +1718,194 @@
id="layer1"
transform="translate(0,-947.36215)">
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+ style="filter:url(#filter8081)"
+ id="g13745"
+ transform="translate(-320.253,5934.7531)">
+
+
+
+
+
+
-
+ style="filter:url(#filter8081)"
+ id="g13761"
+ transform="translate(-320.253,5934.7531)">
+
+
+
+
+
+
+
+
+
+
+
+
+
+
-
+ style="filter:url(#filter8081)"
+ id="g13793"
+ transform="translate(-320.253,5934.7531)">
+
+
+
+
+
+
+
-
-
-
-
-
-
-
-
-
-
+ style="filter:url(#filter8081)"
+ id="g13811"
+ transform="translate(-320.253,5934.7531)">
+
+
+
+
+
+
+
diff --git a/sites/all/themes/gui/jee/assets/img/title-OPP.png b/sites/all/themes/gui/jee/assets/img/title-OPP.png
index 5230597..ab7ac75 100644
Binary files a/sites/all/themes/gui/jee/assets/img/title-OPP.png and b/sites/all/themes/gui/jee/assets/img/title-OPP.png differ
diff --git a/sites/all/themes/gui/jee/assets/img/title-OPP.svg b/sites/all/themes/gui/jee/assets/img/title-OPP.svg
index 4c11a6e..29c9b6c 100644
--- a/sites/all/themes/gui/jee/assets/img/title-OPP.svg
+++ b/sites/all/themes/gui/jee/assets/img/title-OPP.svg
@@ -1675,9 +1675,9 @@
borderopacity="1.0"
inkscape:pageopacity="0.0"
inkscape:pageshadow="2"
- inkscape:zoom="3.959798"
- inkscape:cx="105.87426"
- inkscape:cy="46.675506"
+ inkscape:zoom="2.8"
+ inkscape:cx="84.029306"
+ inkscape:cy="23.024684"
inkscape:document-units="px"
inkscape:current-layer="layer1"
showgrid="false"
@@ -1695,7 +1695,7 @@
image/svg+xml
-
+
@@ -1704,289 +1704,175 @@
inkscape:groupmode="layer"
id="layer1"
transform="translate(0,-957.36215)">
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/sites/all/themes/gui/jee/bower.json b/sites/all/themes/gui/jee/bower.json
index d3903b7..4158556 100644
--- a/sites/all/themes/gui/jee/bower.json
+++ b/sites/all/themes/gui/jee/bower.json
@@ -5,7 +5,8 @@
"jquery.transit": "~0.9.12",
"jquery.pep": "~0.6.3",
"Peppermint": "~1.3.7",
- "vimeo-jquery-api": "~0.9.3"
+ "vimeo-jquery-api": "~0.9.3",
+ "detectizr": "~2.0.0"
},
"version": "7.x-0.1",
"authors": [
diff --git a/sites/all/themes/gui/jee/bower_components/modernizr/.bower.json b/sites/all/themes/gui/jee/bower_components/modernizr/.bower.json
index 82c9f4d..428ac2b 100644
--- a/sites/all/themes/gui/jee/bower_components/modernizr/.bower.json
+++ b/sites/all/themes/gui/jee/bower_components/modernizr/.bower.json
@@ -1,14 +1,14 @@
{
"name": "modernizr",
"homepage": "https://github.com/Modernizr/Modernizr",
- "version": "2.8.3",
- "_release": "2.8.3",
+ "version": "2.7.1",
+ "_release": "2.7.1",
"_resolution": {
"type": "version",
- "tag": "v2.8.3",
- "commit": "d6bb30c0f12ebb3ddd01e90b0bf435e1c34e6f11"
+ "tag": "v2.7.1",
+ "commit": "54252c10fc7d3b8b17cf458c401ca904dc354d8c"
},
"_source": "git://github.com/Modernizr/Modernizr.git",
- "_target": ">= 2.7.2",
+ "_target": "2.7.1",
"_originalSource": "modernizr"
}
\ No newline at end of file
diff --git a/sites/all/themes/gui/jee/bower_components/modernizr/feature-detects/css-shapes.js b/sites/all/themes/gui/jee/bower_components/modernizr/feature-detects/css-shapes.js
deleted file mode 100644
index 2801165..0000000
--- a/sites/all/themes/gui/jee/bower_components/modernizr/feature-detects/css-shapes.js
+++ /dev/null
@@ -1,4 +0,0 @@
-
-// http://html.adobe.com/webplatform/layout/shapes
-
-Modernizr.addTest('shapes', Modernizr.testAllProps('shapeOutside', 'content-box', true));
diff --git a/sites/all/themes/gui/jee/bower_components/modernizr/feature-detects/notification.js b/sites/all/themes/gui/jee/bower_components/modernizr/feature-detects/notification.js
index 92d1eef..4324222 100644
--- a/sites/all/themes/gui/jee/bower_components/modernizr/feature-detects/notification.js
+++ b/sites/all/themes/gui/jee/bower_components/modernizr/feature-detects/notification.js
@@ -7,4 +7,4 @@
// window.Notification only exist in the draft specs
// http://dev.w3.org/2006/webapi/WebNotifications/publish/Notifications.html#idl-if-Notification
-Modernizr.addTest('notification', 'Notification' in window && 'permission' in window.Notification && 'requestPermission' in window.Notification);
+Modernizr.addTest('notification', !!Modernizr.prefixed('Notifications', window));
\ No newline at end of file
diff --git a/sites/all/themes/gui/jee/bower_components/modernizr/feature-detects/websockets-binary.js b/sites/all/themes/gui/jee/bower_components/modernizr/feature-detects/websockets-binary.js
index 8f549ce..8f15c25 100644
--- a/sites/all/themes/gui/jee/bower_components/modernizr/feature-detects/websockets-binary.js
+++ b/sites/all/themes/gui/jee/bower_components/modernizr/feature-detects/websockets-binary.js
@@ -1,20 +1,7 @@
// binaryType is truthy if there is support.. returns "blob" in new-ish chrome.
// plus.google.com/115535723976198353696/posts/ERN6zYozENV
-// github.com/Modernizr/Modernizr/issues/370
-Modernizr.addTest('websocketsbinary', function() {
- var protocol = 'https:'==location.protocol?'wss':'ws',
- protoBin;
-
- if('WebSocket' in window) {
- if( protoBin = 'binaryType' in WebSocket.prototype ) {
- return protoBin;
- }
- try {
- return !!(new WebSocket(protocol+'://.').binaryType);
- } catch (e){}
- }
-
- return false;
-});
+Modernizr.addTest('websocketsbinary',
+ !!(window.WebSocket && (new WebSocket('ws://.')).binaryType)
+);
diff --git a/sites/all/themes/gui/jee/bower_components/modernizr/feature-detects/workers-blobworkers.js b/sites/all/themes/gui/jee/bower_components/modernizr/feature-detects/workers-blobworkers.js
index 33e82eb..509127f 100644
--- a/sites/all/themes/gui/jee/bower_components/modernizr/feature-detects/workers-blobworkers.js
+++ b/sites/all/themes/gui/jee/bower_components/modernizr/feature-detects/workers-blobworkers.js
@@ -7,60 +7,42 @@
(function(){
try {
+
// we're avoiding using Modernizr._domPrefixes as the prefix capitalization on
// these guys are notoriously peculiar.
- var BlobBuilder = window.MozBlobBuilder || window.WebKitBlobBuilder || window.MSBlobBuilder || window.OBlobBuilder || window.BlobBuilder;
- var URL = window.MozURL || window.webkitURL || window.MSURL || window.OURL || window.URL;
+ var BlobBuilder = window.MozBlobBuilder || window.WebKitBlobBuilder || window.MSBlobBuilder || window.OBlobBuilder || window.BlobBuilder,
+ URL = window.MozURL || window.webkitURL || window.MSURL || window.OURL || window.URL;
+
var data = 'Modernizr',
- blob,
- bb,
- worker,
- url,
- timeout,
- scriptText = 'this.onmessage=function(e){postMessage(e.data)}';
+ bb = new BlobBuilder();
- try {
- blob = new Blob([scriptText], {type:'text/javascript'});
- } catch(e) {
- // we'll fall back to the deprecated BlobBuilder
- }
- if (!blob) {
- bb = new BlobBuilder();
- bb.append(scriptText);
- blob = bb.getBlob();
- }
+ bb.append('this.onmessage=function(e){postMessage(e.data)}');
- url = URL.createObjectURL(blob);
- worker = new Worker(url);
+ var url = URL.createObjectURL(bb.getBlob()),
+ worker = new Worker(url);
+
+ bb = null;
worker.onmessage = function(e) {
+ worker.terminate();
+ URL.revokeObjectURL(url);
Modernizr.addTest('blobworkers', data === e.data);
- cleanup();
+ worker = null;
};
// Just in case...
- worker.onerror = fail;
- timeout = setTimeout(fail, 200);
+ worker.onerror = function() {
+ Modernizr.addTest('blobworkers', false);
+ worker = null;
+ };
+
+ setTimeout(function() {
+ Modernizr.addTest('blobworkers', false);
+ }, 200);
worker.postMessage(data);
+
} catch (e) {
- fail();
- }
-
- function fail() {
Modernizr.addTest('blobworkers', false);
- cleanup();
- }
-
- function cleanup() {
- if (url) {
- URL.revokeObjectURL(url);
- }
- if (worker) {
- worker.terminate();
- }
- if (timeout) {
- clearTimeout(timeout);
- }
}
}());
diff --git a/sites/all/themes/gui/jee/bower_components/modernizr/grunt.js b/sites/all/themes/gui/jee/bower_components/modernizr/grunt.js
index ed591da..68c345d 100644
--- a/sites/all/themes/gui/jee/bower_components/modernizr/grunt.js
+++ b/sites/all/themes/gui/jee/bower_components/modernizr/grunt.js
@@ -4,7 +4,7 @@ module.exports = function( grunt ) {
grunt.initConfig({
meta: {
- version: '2.8.3',
+ version: '2.7.1',
banner: '/*!\n' +
' * Modernizr v<%= meta.version %>\n' +
' * www.modernizr.com\n *\n' +
diff --git a/sites/all/themes/gui/jee/bower_components/modernizr/modernizr.js b/sites/all/themes/gui/jee/bower_components/modernizr/modernizr.js
index 3365339..07ea93f 100644
--- a/sites/all/themes/gui/jee/bower_components/modernizr/modernizr.js
+++ b/sites/all/themes/gui/jee/bower_components/modernizr/modernizr.js
@@ -1,5 +1,5 @@
/*!
- * Modernizr v2.8.3
+ * Modernizr v2.7.1
* www.modernizr.com
*
* Copyright (c) Faruk Ates, Paul Irish, Alex Sexton
@@ -24,7 +24,7 @@
window.Modernizr = (function( window, document, undefined ) {
- var version = '2.8.3',
+ var version = '2.7.1',
Modernizr = {},
@@ -156,7 +156,7 @@ window.Modernizr = (function( window, document, undefined ) {
var matchMedia = window.matchMedia || window.msMatchMedia;
if ( matchMedia ) {
- return matchMedia(mq) && matchMedia(mq).matches || false;
+ return matchMedia(mq).matches;
}
var bool;
@@ -605,7 +605,7 @@ window.Modernizr = (function( window, document, undefined ) {
// Note, Android < 4 will pass this test, but can only animate
// a single property at a time
- // goo.gl/v3V4Gp
+ // daneden.me/2011/12/putting-up-with-androids-bullshit/
tests['cssanimations'] = function() {
return testPropsAll('animationName');
};
diff --git a/sites/all/themes/gui/jee/css/jee.css b/sites/all/themes/gui/jee/css/jee.css
index 6501e31..0ea0223 100644
--- a/sites/all/themes/gui/jee/css/jee.css
+++ b/sites/all/themes/gui/jee/css/jee.css
@@ -3741,12 +3741,15 @@ p.heading {
/ ___ |/ ____/ ____/
/_/ |_/_/ /_/
*/
-/* line 45, jee.scss */
+/* line 46, jee.scss */
html {
position: relative;
+ height: 100%;
+ width: 100%;
+ overflow: hidden;
}
-/* line 51, jee.scss */
+/* line 52, jee.scss */
body {
position: relative;
-webkit-user-select: none;
@@ -3758,7 +3761,7 @@ body {
overflow: hidden;
}
-/* line 60, jee.scss */
+/* line 61, jee.scss */
#root {
position: relative;
width: 100%;
@@ -3888,32 +3891,48 @@ body {
opacity: 1;
}
}
-/* line 112, jee.scss */
+/* line 113, jee.scss */
#header {
z-index: 0;
position: absolute;
overflow: hidden;
- width: 700px;
- height: 310px;
- top: 50%;
- left: 50%;
- margin-left: -350px;
- margin-top: -155px;
-webkit-animation-fill-mode: forwards;
animation-fill-mode: forwards;
}
-/* line 126, jee.scss */
+@media only screen and (max-width: 40em) {
+ /* line 113, jee.scss */
+ #header {
+ width: 200px;
+ height: 88px;
+ top: 50%;
+ left: 50%;
+ margin-left: -100px;
+ margin-top: -44px;
+ }
+}
+@media only screen and (min-width: 40.063em) {
+ /* line 113, jee.scss */
+ #header {
+ width: 700px;
+ height: 310px;
+ top: 50%;
+ left: 50%;
+ margin-left: -350px;
+ margin-top: -155px;
+ }
+}
+/* line 136, jee.scss */
#header h1 {
position: absolute;
width: 100%;
height: 100%;
}
-/* line 129, jee.scss */
+/* line 139, jee.scss */
#header h1 a {
display: block;
margin-top: -500%;
}
-/* line 131, jee.scss */
+/* line 141, jee.scss */
#header h1:after, #header h1:before {
content: "";
display: block;
@@ -3924,28 +3943,31 @@ body {
left: 0;
opacity: 0;
}
-/* line 139, jee.scss */
+/* line 149, jee.scss */
#header h1:before {
background: transparent url("../assets/img/logo.png") no-repeat center center;
background: none, url("../assets/img/logo.svg") no-repeat center center;
+ background-size: contain;
-webkit-animation: introLogo 6s linear 0s;
animation: introLogo 6s linear 0s;
-webkit-animation-fill-mode: forwards;
animation-fill-mode: forwards;
}
-/* line 144, jee.scss */
+/* line 155, jee.scss */
#header h1:after {
background: transparent url("../assets/img/logo-blured.png") no-repeat center center;
background: none, url("../assets/img/logo-blured.svg") no-repeat center center;
+ background-size: contain;
-webkit-animation: introLogoBlured 6s linear 0s;
animation: introLogoBlured 6s linear 0s;
-webkit-animation-fill-mode: forwards;
animation-fill-mode: forwards;
}
-/* line 152, jee.scss */
+/* line 164, jee.scss */
#header h2 {
background: transparent url("../assets/img/slogan.png") no-repeat center center;
background: none, url("../assets/img/slogan.svg") no-repeat center center;
+ background-size: contain;
position: absolute;
width: 100%;
height: 100%;
@@ -3955,13 +3977,13 @@ body {
-webkit-animation-fill-mode: forwards;
animation-fill-mode: forwards;
}
-/* line 157, jee.scss */
+/* line 170, jee.scss */
#header h2 a {
display: block;
margin-top: -500%;
}
-/* line 164, jee.scss */
+/* line 177, jee.scss */
div.messages {
position: absolute;
top: 20px;
@@ -3972,7 +3994,7 @@ div.messages {
z-index: 1000;
}
-/* line 172, jee.scss */
+/* line 185, jee.scss */
#main {
position: absolute;
width: 100%;
@@ -3999,280 +4021,378 @@ div.messages {
\____/_/ /_____/_/ |_/_____/_____/ \____/_/ /_/_/ |_/_/ /_/ /_____/_/ |_|/____/
*/
}
-/* line 178, jee.scss */
+/* line 191, jee.scss */
#main .block-system {
position: relative;
width: 100%;
height: 100%;
overflow: hidden;
}
-/* line 194, jee.scss */
+/* line 219, jee.scss */
#main #node-2.node-teaser::after {
background: transparent url("../assets/img/bgd-sol.png") no-repeat center center;
background: none, url("../assets/img/bgd-sol.svg") no-repeat center center;
}
-/* line 195, jee.scss */
+/* line 220, jee.scss */
#main #node-2.node-teaser, #main #node-2.node-teaser a {
color: #b24c14;
}
-/* line 197, jee.scss */
+/* line 222, jee.scss */
#main #node-2.node-teaser h2.node-title, #main #node-2.node-teaser h2.node-title a {
color: #d85509;
}
-/* line 198, jee.scss */
+/* line 223, jee.scss */
#main #node-2.node-teaser h2.node-title a {
background: transparent url("../assets/img/title-SOL.png") no-repeat center center;
background: none, url("../assets/img/title-SOL.svg") no-repeat center center;
- width: 170px;
- height: 35px;
+ background-size: contain;
}
-/* line 200, jee.scss */
+@media only screen and (max-width: 40em) {
+ /* line 223, jee.scss */
+ #main #node-2.node-teaser h2.node-title a {
+ width: 85px;
+ height: 17.5px;
+ margin: 0 34px;
+ }
+}
+@media only screen and (min-width: 40.063em) {
+ /* line 223, jee.scss */
+ #main #node-2.node-teaser h2.node-title a {
+ width: 170px;
+ height: 35px;
+ }
+}
+/* line 229, jee.scss */
#main #node-2.node-teaser .field-name-field-vignette {
background: transparent url("../assets/img/shadow-sol.png") no-repeat center center;
background: none, url("../assets/img/shadow-sol.svg") no-repeat center center;
}
-/* line 201, jee.scss */
+/* line 230, jee.scss */
#main #node-2.node-teaser .line {
background-color: #ea5b0c;
}
-/* line 204, jee.scss */
+/* line 233, jee.scss */
#main #node-2.node-teaser.previewed h2.node-title, #main #node-2.node-teaser.previewed h2.node-title a {
color: #ea5b0c;
}
-/* line 205, jee.scss */
+/* line 234, jee.scss */
#main #node-2.node-teaser.previewed h2.node-title a {
background: transparent url("../assets/img/title-SOL-activ.png") no-repeat center center;
background: none, url("../assets/img/title-SOL-activ.svg") no-repeat center center;
}
-/* line 213, jee.scss */
+/* line 242, jee.scss */
#main #node-3.node-teaser::after {
background: transparent url("../assets/img/bgd-dph.png") no-repeat center center;
background: none, url("../assets/img/bgd-dph.svg") no-repeat center center;
}
-/* line 214, jee.scss */
+/* line 243, jee.scss */
#main #node-3.node-teaser, #main #node-3.node-teaser a {
color: #686b00;
}
-/* line 216, jee.scss */
+/* line 245, jee.scss */
#main #node-3.node-teaser h2.node-title, #main #node-3.node-teaser h2.node-title a {
color: #afaf00;
}
-/* line 217, jee.scss */
+/* line 246, jee.scss */
#main #node-3.node-teaser h2.node-title a {
background: transparent url("../assets/img/title-DPH.png") no-repeat center center;
background: none, url("../assets/img/title-DPH.svg") no-repeat center center;
- width: 180px;
- height: 80px;
+ background-size: contain;
}
-/* line 219, jee.scss */
+@media only screen and (max-width: 40em) {
+ /* line 246, jee.scss */
+ #main #node-3.node-teaser h2.node-title a {
+ width: 90px;
+ height: 40px;
+ margin: 0 36px;
+ }
+}
+@media only screen and (min-width: 40.063em) {
+ /* line 246, jee.scss */
+ #main #node-3.node-teaser h2.node-title a {
+ width: 180px;
+ height: 80px;
+ }
+}
+/* line 252, jee.scss */
#main #node-3.node-teaser .field-name-field-vignette {
background: transparent url("../assets/img/shadow-dph.png") no-repeat center center;
background: none, url("../assets/img/shadow-dph.svg") no-repeat center center;
}
-/* line 220, jee.scss */
+/* line 253, jee.scss */
#main #node-3.node-teaser .line {
background-color: #cecd00;
}
-/* line 223, jee.scss */
+/* line 256, jee.scss */
#main #node-3.node-teaser.previewed h2.node-title, #main #node-3.node-teaser.previewed h2.node-title a {
color: #cecd00;
}
-/* line 224, jee.scss */
+/* line 257, jee.scss */
#main #node-3.node-teaser.previewed h2.node-title a {
background: transparent url("../assets/img/title-DPH-activ.png") no-repeat center center;
background: none, url("../assets/img/title-DPH-activ.svg") no-repeat center center;
}
-/* line 232, jee.scss */
+/* line 265, jee.scss */
#main #node-4.node-teaser::after {
background: transparent url("../assets/img/bgd-sub.png") no-repeat center center;
background: none, url("../assets/img/bgd-sub.svg") no-repeat center center;
}
-/* line 233, jee.scss */
+/* line 266, jee.scss */
#main #node-4.node-teaser, #main #node-4.node-teaser a {
color: #b71330;
}
-/* line 235, jee.scss */
+/* line 268, jee.scss */
#main #node-4.node-teaser h2.node-title, #main #node-4.node-teaser h2.node-title a {
color: #cd0734;
}
-/* line 236, jee.scss */
+/* line 269, jee.scss */
#main #node-4.node-teaser h2.node-title a {
background: transparent url("../assets/img/title-SUB.png") no-repeat center center;
background: none, url("../assets/img/title-SUB.svg") no-repeat center center;
- width: 200px;
- height: 35px;
+ background-size: contain;
}
-/* line 238, jee.scss */
+@media only screen and (max-width: 40em) {
+ /* line 269, jee.scss */
+ #main #node-4.node-teaser h2.node-title a {
+ width: 100px;
+ height: 17.5px;
+ margin: 0 40px;
+ }
+}
+@media only screen and (min-width: 40.063em) {
+ /* line 269, jee.scss */
+ #main #node-4.node-teaser h2.node-title a {
+ width: 200px;
+ height: 35px;
+ }
+}
+/* line 275, jee.scss */
#main #node-4.node-teaser .field-name-field-vignette {
background: transparent url("../assets/img/shadow-sub.png") no-repeat center center;
background: none, url("../assets/img/shadow-sub.svg") no-repeat center center;
}
-/* line 239, jee.scss */
+/* line 276, jee.scss */
#main #node-4.node-teaser .line {
background-color: #de003a;
}
-/* line 242, jee.scss */
+/* line 279, jee.scss */
#main #node-4.node-teaser.previewed h2.node-title, #main #node-4.node-teaser.previewed h2.node-title a {
color: #de003a;
}
-/* line 243, jee.scss */
+/* line 280, jee.scss */
#main #node-4.node-teaser.previewed h2.node-title a {
background: transparent url("../assets/img/title-SUB-activ.png") no-repeat center center;
background: none, url("../assets/img/title-SUB-activ.svg") no-repeat center center;
}
-/* line 251, jee.scss */
+/* line 288, jee.scss */
#main #node-5.node-teaser::after {
background: transparent url("../assets/img/bgd-bc.png") no-repeat center center;
background: none, url("../assets/img/bgd-bc.svg") no-repeat center center;
}
-/* line 252, jee.scss */
+/* line 289, jee.scss */
#main #node-5.node-teaser, #main #node-5.node-teaser a {
color: #033d6f;
}
-/* line 254, jee.scss */
+/* line 291, jee.scss */
#main #node-5.node-teaser h2.node-title, #main #node-5.node-teaser h2.node-title a {
color: #024b87;
}
-/* line 255, jee.scss */
+/* line 292, jee.scss */
#main #node-5.node-teaser h2.node-title a {
background: transparent url("../assets/img/title-BC.png") no-repeat center center;
background: none, url("../assets/img/title-BC.svg") no-repeat center center;
- width: 120px;
- height: 45px;
+ background-size: contain;
}
-/* line 257, jee.scss */
+@media only screen and (max-width: 40em) {
+ /* line 292, jee.scss */
+ #main #node-5.node-teaser h2.node-title a {
+ width: 60px;
+ height: 22.5px;
+ margin: 0 24px;
+ }
+}
+@media only screen and (min-width: 40.063em) {
+ /* line 292, jee.scss */
+ #main #node-5.node-teaser h2.node-title a {
+ width: 120px;
+ height: 45px;
+ }
+}
+/* line 298, jee.scss */
#main #node-5.node-teaser .field-name-field-vignette {
background: transparent url("../assets/img/shadow-bc.png") no-repeat center center;
background: none, url("../assets/img/shadow-bc.svg") no-repeat center center;
}
-/* line 258, jee.scss */
+/* line 299, jee.scss */
#main #node-5.node-teaser .line {
background-color: #0066b1;
}
-/* line 261, jee.scss */
+/* line 302, jee.scss */
#main #node-5.node-teaser.previewed h2.node-title, #main #node-5.node-teaser.previewed h2.node-title a {
color: #0066b1;
}
-/* line 262, jee.scss */
+/* line 303, jee.scss */
#main #node-5.node-teaser.previewed h2.node-title a {
background: transparent url("../assets/img/title-BC-activ.png") no-repeat center center;
background: none, url("../assets/img/title-BC-activ.svg") no-repeat center center;
}
-/* line 270, jee.scss */
+/* line 311, jee.scss */
#main #node-6.node-teaser::after {
background: transparent url("../assets/img/bgd-opp.png") no-repeat center center;
background: none, url("../assets/img/bgd-opp.svg") no-repeat center center;
}
-/* line 271, jee.scss */
+/* line 312, jee.scss */
#main #node-6.node-teaser, #main #node-6.node-teaser a {
color: #7f1965;
}
-/* line 273, jee.scss */
+/* line 314, jee.scss */
#main #node-6.node-teaser h2.node-title, #main #node-6.node-teaser h2.node-title a {
color: #941b80;
}
-/* line 274, jee.scss */
+/* line 315, jee.scss */
#main #node-6.node-teaser h2.node-title a {
background: transparent url("../assets/img/title-OPP.png") no-repeat center center;
background: none, url("../assets/img/title-OPP.svg") no-repeat center center;
- width: 245px;
- height: 95px;
+ background-size: contain;
}
-/* line 276, jee.scss */
+@media only screen and (max-width: 40em) {
+ /* line 315, jee.scss */
+ #main #node-6.node-teaser h2.node-title a {
+ width: 122.5px;
+ height: 47.5px;
+ margin: 0 49px;
+ }
+}
+@media only screen and (min-width: 40.063em) {
+ /* line 315, jee.scss */
+ #main #node-6.node-teaser h2.node-title a {
+ width: 245px;
+ height: 95px;
+ }
+}
+/* line 321, jee.scss */
#main #node-6.node-teaser .field-name-field-vignette {
background: transparent url("../assets/img/shadow-opp.png") no-repeat center center;
background: none, url("../assets/img/shadow-opp.svg") no-repeat center center;
}
-/* line 277, jee.scss */
+/* line 322, jee.scss */
#main #node-6.node-teaser .line {
background-color: #af1380;
}
-/* line 280, jee.scss */
+/* line 325, jee.scss */
#main #node-6.node-teaser.previewed h2.node-title, #main #node-6.node-teaser.previewed h2.node-title a {
color: #af1380;
}
-/* line 281, jee.scss */
+/* line 326, jee.scss */
#main #node-6.node-teaser.previewed h2.node-title a {
background: transparent url("../assets/img/title-OPP-activ.png") no-repeat center center;
background: none, url("../assets/img/title-OPP-activ.svg") no-repeat center center;
}
-/* line 289, jee.scss */
+/* line 334, jee.scss */
#main #node-7.node-teaser::after {
background: transparent url("../assets/img/bgd-dub.png") no-repeat center center;
background: none, url("../assets/img/bgd-dub.svg") no-repeat center center;
}
-/* line 290, jee.scss */
+/* line 335, jee.scss */
#main #node-7.node-teaser, #main #node-7.node-teaser a {
color: #22742c;
}
-/* line 292, jee.scss */
+/* line 337, jee.scss */
#main #node-7.node-teaser h2.node-title, #main #node-7.node-teaser h2.node-title a {
color: #288d80;
}
-/* line 293, jee.scss */
+/* line 338, jee.scss */
#main #node-7.node-teaser h2.node-title a {
background: transparent url("../assets/img/title-DUB.png") no-repeat center center;
background: none, url("../assets/img/title-DUB.svg") no-repeat center center;
- width: 195px;
- height: 65px;
+ background-size: contain;
}
-/* line 295, jee.scss */
+@media only screen and (max-width: 40em) {
+ /* line 338, jee.scss */
+ #main #node-7.node-teaser h2.node-title a {
+ width: 97.5px;
+ height: 32.5px;
+ margin: 0 39px;
+ }
+}
+@media only screen and (min-width: 40.063em) {
+ /* line 338, jee.scss */
+ #main #node-7.node-teaser h2.node-title a {
+ width: 195px;
+ height: 65px;
+ }
+}
+/* line 344, jee.scss */
#main #node-7.node-teaser .field-name-field-vignette {
background: transparent url("../assets/img/shadow-dub.png") no-repeat center center;
background: none, url("../assets/img/shadow-dub.svg") no-repeat center center;
}
-/* line 296, jee.scss */
+/* line 345, jee.scss */
#main #node-7.node-teaser .line {
background-color: #62a530;
}
-/* line 299, jee.scss */
+/* line 348, jee.scss */
#main #node-7.node-teaser.previewed h2.node-title, #main #node-7.node-teaser.previewed h2.node-title a {
color: #62a530;
}
-/* line 300, jee.scss */
+/* line 349, jee.scss */
#main #node-7.node-teaser.previewed h2.node-title a {
background: transparent url("../assets/img/title-DUB-activ.png") no-repeat center center;
background: none, url("../assets/img/title-DUB-activ.svg") no-repeat center center;
}
-/* line 308, jee.scss */
+/* line 357, jee.scss */
#main #node-8.node-teaser::after {
background: transparent url("../assets/img/bgd-juso.png") no-repeat center center;
background: none, url("../assets/img/bgd-juso.svg") no-repeat center center;
}
-/* line 309, jee.scss */
+/* line 358, jee.scss */
#main #node-8.node-teaser, #main #node-8.node-teaser a {
color: #0b7f8a;
}
-/* line 311, jee.scss */
+/* line 360, jee.scss */
#main #node-8.node-teaser h2.node-title, #main #node-8.node-teaser h2.node-title a {
color: #009aa8;
}
-/* line 312, jee.scss */
+/* line 361, jee.scss */
#main #node-8.node-teaser h2.node-title a {
background: transparent url("../assets/img/title-JUSO.png") no-repeat center center;
background: none, url("../assets/img/title-JUSO.svg") no-repeat center center;
- width: 200px;
- height: 65px;
+ background-size: contain;
}
-/* line 314, jee.scss */
+@media only screen and (max-width: 40em) {
+ /* line 361, jee.scss */
+ #main #node-8.node-teaser h2.node-title a {
+ width: 100px;
+ height: 32.5px;
+ margin: 0 40px;
+ }
+}
+@media only screen and (min-width: 40.063em) {
+ /* line 361, jee.scss */
+ #main #node-8.node-teaser h2.node-title a {
+ width: 200px;
+ height: 65px;
+ }
+}
+/* line 367, jee.scss */
#main #node-8.node-teaser .field-name-field-vignette {
background: transparent url("../assets/img/shadow-juso.png") no-repeat center center;
background: none, url("../assets/img/shadow-juso.svg") no-repeat center center;
}
-/* line 315, jee.scss */
+/* line 368, jee.scss */
#main #node-8.node-teaser .line {
background-color: #33b4b5;
}
-/* line 318, jee.scss */
+/* line 371, jee.scss */
#main #node-8.node-teaser.previewed h2.node-title, #main #node-8.node-teaser.previewed h2.node-title a {
color: #33b4b5;
}
-/* line 319, jee.scss */
+/* line 372, jee.scss */
#main #node-8.node-teaser.previewed h2.node-title a {
background: transparent url("../assets/img/title-JUSO-activ.png") no-repeat center center;
background: none, url("../assets/img/title-JUSO-activ.svg") no-repeat center center;
}
-/* line 334, jee.scss */
+/* line 387, jee.scss */
#main .node-chapitre.node-teaser {
z-index: 2;
position: absolute;
@@ -4324,15 +4444,15 @@ div.messages {
|_| /_/
*/
}
-/* line 358, jee.scss */
+/* line 411, jee.scss */
#main .node-chapitre.node-teaser.enabled {
opacity: 1;
}
-/* line 362, jee.scss */
+/* line 415, jee.scss */
#main .node-chapitre.node-teaser h2.node-title {
cursor: pointer;
}
-/* line 364, jee.scss */
+/* line 417, jee.scss */
#main .node-chapitre.node-teaser h2.node-title a {
-webkit-transform: none;
-ms-transform: none;
@@ -4346,11 +4466,12 @@ div.messages {
transition-property: transform;
z-index: 5;
}
-/* line 372, jee.scss */
+/* line 425, jee.scss */
#main .node-chapitre.node-teaser > .content {
position: relative;
+ left: 0;
}
-/* line 373, jee.scss */
+/* line 426, jee.scss */
#main .node-chapitre.node-teaser .texts {
opacity: 0;
height: 1px;
@@ -4361,7 +4482,7 @@ div.messages {
transition-property: opacity height;
position: absolute;
}
-/* line 379, jee.scss */
+/* line 432, jee.scss */
#main .node-chapitre.node-teaser .field-name-field-partie {
opacity: 0;
position: absolute;
@@ -4370,12 +4491,12 @@ div.messages {
-webkit-transition-property: opacity -webkit-transform;
transition-property: opacity transform;
}
-/* line 385, jee.scss */
+/* line 438, jee.scss */
#main .node-chapitre.node-teaser .field-name-field-partie:nth-child(2) {
z-index: 2;
opacity: 1;
}
-/* line 389, jee.scss */
+/* line 442, jee.scss */
#main .node-chapitre.node-teaser .field-name-field-partie:nth-child(2) > .field-type-text {
opacity: 0;
-webkit-transition: 0.7s ease-out 0.9s;
@@ -4383,7 +4504,7 @@ div.messages {
-webkit-transition-property: opacity;
transition-property: opacity;
}
-/* line 394, jee.scss */
+/* line 447, jee.scss */
#main .node-chapitre.node-teaser .field-name-field-partie:nth-child(2) > .field-name-field-vignette {
cursor: pointer;
z-index: 2;
@@ -4395,7 +4516,7 @@ div.messages {
-webkit-transition-property: -webkit-transform;
transition-property: transform;
}
-/* line 401, jee.scss */
+/* line 454, jee.scss */
#main .node-chapitre.node-teaser:after {
opacity: 0;
-webkit-transition: 2s ease-in;
@@ -4407,15 +4528,15 @@ div.messages {
bottom: 2px;
right: 2px;
}
-/* line 407, jee.scss */
+/* line 460, jee.scss */
#main .node-chapitre.node-teaser .line {
opacity: 0;
}
-/* line 420, jee.scss */
+/* line 473, jee.scss */
#main .node-chapitre.node-teaser.previewed {
z-index: 100;
}
-/* line 422, jee.scss */
+/* line 475, jee.scss */
#main .node-chapitre.node-teaser.previewed:after {
opacity: 1;
top: 2em;
@@ -4423,55 +4544,55 @@ div.messages {
right: -12em;
bottom: -30em;
}
-/* line 429, jee.scss */
+/* line 482, jee.scss */
#main .node-chapitre.node-teaser.previewed h2.node-title a {
-webkit-transform: scale(2, 2);
-ms-transform: scale(2, 2);
transform: scale(2, 2);
}
-/* line 430, jee.scss */
+/* line 483, jee.scss */
#main .node-chapitre.node-teaser.previewed .texts {
opacity: 1;
height: 8em;
}
-/* line 431, jee.scss */
+/* line 484, jee.scss */
#main .node-chapitre.node-teaser.previewed .field-name-field-partie {
opacity: 1;
z-index: 0;
}
-/* line 434, jee.scss */
+/* line 487, jee.scss */
#main .node-chapitre.node-teaser.previewed .field-name-field-partie > .field {
opacity: 1;
z-index: -1;
cursor: default;
}
-/* line 436, jee.scss */
+/* line 489, jee.scss */
#main .node-chapitre.node-teaser.previewed .field-name-field-partie:nth-child(2) > .field-name-field-vignette {
-webkit-transform: scale(1.3);
-ms-transform: scale(1.3);
transform: scale(1.3);
}
-/* line 441, jee.scss */
+/* line 494, jee.scss */
#main .node-chapitre.node-teaser.previewed .field-name-field-partie .field-name-field-vignette {
z-index: 2;
cursor: pointer;
}
-/* line 456, jee.scss */
+/* line 509, jee.scss */
#main .node-chapitre.node-teaser.mitigated {
opacity: 0.2;
}
-/* line 467, jee.scss */
+/* line 520, jee.scss */
.chapter-displayed #main .node-chapitre.node-teaser {
opacity: 0.05;
}
-/* line 479, jee.scss */
+/* line 532, jee.scss */
#main .node-chapitre.node-teaser:after {
content: " ";
background-size: contain !important;
position: absolute;
z-index: -1;
}
-/* line 486, jee.scss */
+/* line 539, jee.scss */
#main .node-chapitre.node-teaser h2.node-title {
font-family: "epflulb";
font-weight: normal;
@@ -4482,36 +4603,36 @@ div.messages {
z-index: 5;
}
@media only screen and (min-width: 64.063em) {
- /* line 486, jee.scss */
+ /* line 539, jee.scss */
#main .node-chapitre.node-teaser h2.node-title {
font-size: 1.3em;
}
}
@media only screen and (min-width: 90.063em) {
- /* line 486, jee.scss */
+ /* line 539, jee.scss */
#main .node-chapitre.node-teaser h2.node-title {
font-size: 1.8em;
}
}
-/* line 500, jee.scss */
+/* line 553, jee.scss */
#main .node-chapitre.node-teaser h2.node-title a {
display: block;
text-indent: -1000px;
overflow: hidden;
}
-/* line 512, jee.scss */
+/* line 565, jee.scss */
#main .node-chapitre.node-teaser .field-name-field-accroche {
min-width: 19em;
}
-/* line 513, jee.scss */
+/* line 566, jee.scss */
#main .node-chapitre.node-teaser .field-name-field-accroche h1, #main .node-chapitre.node-teaser .field-name-field-accroche h2, #main .node-chapitre.node-teaser .field-name-field-accroche h3, #main .node-chapitre.node-teaser .field-name-field-accroche h4, #main .node-chapitre.node-teaser .field-name-field-accroche h5, #main .node-chapitre.node-teaser .field-name-field-accroche h6 {
display: none !important;
}
-/* line 515, jee.scss */
+/* line 568, jee.scss */
#main .node-chapitre.node-teaser .field-name-field-accroche p {
margin: 0;
}
-/* line 519, jee.scss */
+/* line 572, jee.scss */
#main .node-chapitre.node-teaser ul.links {
display: block;
margin: 0;
@@ -4520,11 +4641,11 @@ div.messages {
position: relative;
width: 100%;
}
-/* line 521, jee.scss */
+/* line 574, jee.scss */
#main .node-chapitre.node-teaser ul.links li.node-readmore {
padding: 0;
}
-/* line 523, jee.scss */
+/* line 576, jee.scss */
#main .node-chapitre.node-teaser ul.links li.node-readmore a {
display: inline-block;
height: 25px;
@@ -4536,12 +4657,17 @@ div.messages {
background: transparent url("../assets/img/readmore-btn.png") no-repeat right center;
background: none, url("../assets/img/readmore-btn.svg") no-repeat right center;
}
-/* line 536, jee.scss */
+/* line 589, jee.scss */
#main .node-chapitre.node-teaser .field-name-field-partie {
clear: both;
- padding-top: 1em;
}
-/* line 540, jee.scss */
+@media only screen and (min-width: 40.063em) {
+ /* line 589, jee.scss */
+ #main .node-chapitre.node-teaser .field-name-field-partie {
+ padding-top: 1em;
+ }
+}
+/* line 597, jee.scss */
#main .node-chapitre.node-teaser .field-name-field-vignette {
position: relative;
float: left;
@@ -4552,33 +4678,33 @@ div.messages {
margin-left: 0;
background-size: contain;
}
-/* line 551, jee.scss */
+/* line 608, jee.scss */
#main .node-chapitre.node-teaser .field-name-field-vignette img {
width: 65px;
height: 65px;
}
-/* line 555, jee.scss */
+/* line 612, jee.scss */
#main .node-chapitre.node-teaser .field-type-text {
min-width: 16em;
}
-/* line 556, jee.scss */
+/* line 613, jee.scss */
#main .node-chapitre.node-teaser .field-name-field-titre {
font-family: "epflul";
font-size: 1.4em;
line-height: 1.1;
}
-/* line 561, jee.scss */
+/* line 618, jee.scss */
#main .node-chapitre.node-teaser .field-name-field-sous-titre {
font-family: "epflul";
font-size: 1.2em;
line-height: 1.2;
}
-/* line 566, jee.scss */
+/* line 623, jee.scss */
#main .node-chapitre.node-teaser .field-name-field-description {
font-size: 0.88em;
line-height: 1;
}
-/* line 572, jee.scss */
+/* line 629, jee.scss */
#main .node-chapitre.node-teaser .line {
z-index: -1;
position: absolute;
@@ -4590,13 +4716,14 @@ div.messages {
width: 2px;
opacity: 0.4;
}
-/* line 590, jee.scss */
+/* line 647, jee.scss */
#main #chapter-wrapper {
position: absolute;
top: 0;
left: 0;
width: 100%;
height: 100%;
+ overflow: hidden;
z-index: -1;
opacity: 0;
-webkit-transition: 2s ease-out;
@@ -4617,12 +4744,12 @@ div.messages {
|__|
*/
}
-/* line 599, jee.scss */
+/* line 657, jee.scss */
#main #chapter-wrapper.visible {
opacity: 1;
z-index: 500;
}
-/* line 604, jee.scss */
+/* line 662, jee.scss */
#main #chapter-wrapper #home-btn {
background: transparent url("../assets/img/home-btn.png") no-repeat center center;
background: none, url("../assets/img/home-btn.svg") no-repeat center center;
@@ -4634,195 +4761,300 @@ div.messages {
height: 20px;
cursor: pointer;
}
-/* line 619, jee.scss */
+/* line 677, jee.scss */
#main #chapter-wrapper #node-2 {
background: transparent url("../assets/img/bgd-sol.png") no-repeat center center;
background: none, url("../assets/img/bgd-sol.svg") no-repeat center center;
}
-/* line 621, jee.scss */
+/* line 679, jee.scss */
#main #chapter-wrapper #node-2 .field-type-text-long .field-label,
#main #chapter-wrapper #node-2 h2.node-title,
#main #chapter-wrapper #node-2 .field-name-field-dbatre li:before,
#main #chapter-wrapper #node-2 .field-name-field-partager .field-label {
color: #ea5b0c;
}
-/* line 627, jee.scss */
-#main #chapter-wrapper #node-2 h2.node-title {
- background: transparent url("../assets/img/title-SOL-blur.png") no-repeat center center;
- background: none, url("../assets/img/title-SOL-blur.svg") no-repeat center center;
+@media only screen and (max-width: 40em) {
+ /* line 686, jee.scss */
+ #main #chapter-wrapper #node-2 h2.node-title {
+ background: transparent url("../assets/img/title-SOL-activ.png") no-repeat center center;
+ background: none, url("../assets/img/title-SOL-activ.svg") no-repeat center center;
+ height: 1.5em;
+ }
}
-/* line 630, jee.scss */
+@media only screen and (min-width: 40.063em) {
+ /* line 692, jee.scss */
+ #main #chapter-wrapper #node-2 h2.node-title {
+ background: transparent url("../assets/img/title-SOL-blur.png") no-repeat center center;
+ background: none, url("../assets/img/title-SOL-blur.svg") no-repeat center center;
+ }
+}
+/* line 696, jee.scss */
#main #chapter-wrapper #node-3 {
background: transparent url("../assets/img/bgd-dph.png") no-repeat center center;
background: none, url("../assets/img/bgd-dph.svg") no-repeat center center;
}
-/* line 632, jee.scss */
+/* line 698, jee.scss */
#main #chapter-wrapper #node-3 .field-type-text-long .field-label,
#main #chapter-wrapper #node-3 h2.node-title,
#main #chapter-wrapper #node-3 .field-name-field-dbatre li:before,
#main #chapter-wrapper #node-3 .field-name-field-partager .field-label {
color: #cecd00;
}
-/* line 638, jee.scss */
-#main #chapter-wrapper #node-3 h2.node-title {
- background: transparent url("../assets/img/title-DPH-blur.png") no-repeat center center;
- background: none, url("../assets/img/title-DPH-blur.svg") no-repeat center center;
+@media only screen and (max-width: 40em) {
+ /* line 705, jee.scss */
+ #main #chapter-wrapper #node-3 h2.node-title {
+ background: transparent url("../assets/img/title-DPH-activ.png") no-repeat center center;
+ background: none, url("../assets/img/title-DPH-activ.svg") no-repeat center center;
+ height: 5em;
+ }
}
-/* line 641, jee.scss */
+@media only screen and (min-width: 40.063em) {
+ /* line 711, jee.scss */
+ #main #chapter-wrapper #node-3 h2.node-title {
+ background: transparent url("../assets/img/title-DPH-blur.png") no-repeat center center;
+ background: none, url("../assets/img/title-DPH-blur.svg") no-repeat center center;
+ }
+}
+/* line 715, jee.scss */
#main #chapter-wrapper #node-4 {
background: transparent url("../assets/img/bgd-sub.png") no-repeat center center;
background: none, url("../assets/img/bgd-sub.svg") no-repeat center center;
}
-/* line 643, jee.scss */
+/* line 717, jee.scss */
#main #chapter-wrapper #node-4 .field-type-text-long .field-label,
#main #chapter-wrapper #node-4 h2.node-title,
#main #chapter-wrapper #node-4 .field-name-field-dbatre li:before,
#main #chapter-wrapper #node-4 .field-name-field-partager .field-label {
color: #de003a;
}
-/* line 649, jee.scss */
-#main #chapter-wrapper #node-4 h2.node-title {
- background: transparent url("../assets/img/title-SUB-blur.png") no-repeat center center;
- background: none, url("../assets/img/title-SUB-blur.svg") no-repeat center center;
+@media only screen and (max-width: 40em) {
+ /* line 724, jee.scss */
+ #main #chapter-wrapper #node-4 h2.node-title {
+ background: transparent url("../assets/img/title-SUB-activ.png") no-repeat center center;
+ background: none, url("../assets/img/title-SUB-activ.svg") no-repeat center center;
+ height: 1.5em;
+ }
}
-/* line 652, jee.scss */
+@media only screen and (min-width: 40.063em) {
+ /* line 730, jee.scss */
+ #main #chapter-wrapper #node-4 h2.node-title {
+ background: transparent url("../assets/img/title-SUB-blur.png") no-repeat center center;
+ background: none, url("../assets/img/title-SUB-blur.svg") no-repeat center center;
+ }
+}
+/* line 734, jee.scss */
#main #chapter-wrapper #node-5 {
background: transparent url("../assets/img/bgd-bc.png") no-repeat center center;
background: none, url("../assets/img/bgd-bc.svg") no-repeat center center;
}
-/* line 654, jee.scss */
+/* line 736, jee.scss */
#main #chapter-wrapper #node-5 .field-type-text-long .field-label,
#main #chapter-wrapper #node-5 h2.node-title,
#main #chapter-wrapper #node-5 .field-name-field-dbatre li:before,
#main #chapter-wrapper #node-5 .field-name-field-partager .field-label {
color: #0066b1;
}
-/* line 660, jee.scss */
-#main #chapter-wrapper #node-5 h2.node-title {
- background: transparent url("../assets/img/title-BC-blur.png") no-repeat center center;
- background: none, url("../assets/img/title-BC-blur.svg") no-repeat center center;
+@media only screen and (max-width: 40em) {
+ /* line 743, jee.scss */
+ #main #chapter-wrapper #node-5 h2.node-title {
+ background: transparent url("../assets/img/title-BC-activ.png") no-repeat center center;
+ background: none, url("../assets/img/title-BC-activ.svg") no-repeat center center;
+ height: 4em;
+ }
}
-/* line 663, jee.scss */
+@media only screen and (min-width: 40.063em) {
+ /* line 749, jee.scss */
+ #main #chapter-wrapper #node-5 h2.node-title {
+ background: transparent url("../assets/img/title-BC-blur.png") no-repeat center center;
+ background: none, url("../assets/img/title-BC-blur.svg") no-repeat center center;
+ }
+}
+/* line 753, jee.scss */
#main #chapter-wrapper #node-6 {
background: transparent url("../assets/img/bgd-opp.png") no-repeat center center;
background: none, url("../assets/img/bgd-opp.svg") no-repeat center center;
}
-/* line 665, jee.scss */
+/* line 755, jee.scss */
#main #chapter-wrapper #node-6 .field-type-text-long .field-label,
#main #chapter-wrapper #node-6 h2.node-title,
#main #chapter-wrapper #node-6 .field-name-field-dbatre li:before,
#main #chapter-wrapper #node-6 .field-name-field-partager .field-label {
color: #af1380;
}
-/* line 671, jee.scss */
-#main #chapter-wrapper #node-6 h2.node-title {
- background: transparent url("../assets/img/title-OPP-blur.png") no-repeat center center;
- background: none, url("../assets/img/title-OPP-blur.svg") no-repeat center center;
+@media only screen and (max-width: 40em) {
+ /* line 762, jee.scss */
+ #main #chapter-wrapper #node-6 h2.node-title {
+ background: transparent url("../assets/img/title-OPP-activ.png") no-repeat center center;
+ background: none, url("../assets/img/title-OPP-activ.svg") no-repeat center center;
+ height: 6em;
+ }
}
-/* line 674, jee.scss */
+@media only screen and (min-width: 40.063em) {
+ /* line 768, jee.scss */
+ #main #chapter-wrapper #node-6 h2.node-title {
+ background: transparent url("../assets/img/title-OPP-blur.png") no-repeat center center;
+ background: none, url("../assets/img/title-OPP-blur.svg") no-repeat center center;
+ }
+}
+/* line 772, jee.scss */
#main #chapter-wrapper #node-7 {
background: transparent url("../assets/img/bgd-bub.png") no-repeat center center;
background: none, url("../assets/img/bgd-bub.svg") no-repeat center center;
}
-/* line 676, jee.scss */
+/* line 774, jee.scss */
#main #chapter-wrapper #node-7 .field-type-text-long .field-label,
#main #chapter-wrapper #node-7 h2.node-title,
#main #chapter-wrapper #node-7 .field-name-field-dbatre li:before,
#main #chapter-wrapper #node-7 .field-name-field-partager .field-label {
color: #62a530;
}
-/* line 682, jee.scss */
-#main #chapter-wrapper #node-7 h2.node-title {
- background: transparent url("../assets/img/title-DUB-blur.png") no-repeat center center;
- background: none, url("../assets/img/title-DUB-blur.svg") no-repeat center center;
+@media only screen and (max-width: 40em) {
+ /* line 781, jee.scss */
+ #main #chapter-wrapper #node-7 h2.node-title {
+ background: transparent url("../assets/img/title-DUB-activ.png") no-repeat center center;
+ background: none, url("../assets/img/title-DUB-activ.svg") no-repeat center center;
+ height: 5em;
+ }
}
-/* line 685, jee.scss */
+@media only screen and (min-width: 40.063em) {
+ /* line 787, jee.scss */
+ #main #chapter-wrapper #node-7 h2.node-title {
+ background: transparent url("../assets/img/title-DUB-blur.png") no-repeat center center;
+ background: none, url("../assets/img/title-DUB-blur.svg") no-repeat center center;
+ }
+}
+/* line 791, jee.scss */
#main #chapter-wrapper #node-8 {
background: transparent url("../assets/img/bgd-juso.png") no-repeat center center;
background: none, url("../assets/img/bgd-juso.svg") no-repeat center center;
}
-/* line 687, jee.scss */
+/* line 793, jee.scss */
#main #chapter-wrapper #node-8 .field-type-text-long .field-label,
#main #chapter-wrapper #node-8 h2.node-title,
#main #chapter-wrapper #node-8 .field-name-field-dbatre li:before,
#main #chapter-wrapper #node-8 .field-name-field-partager .field-label {
color: #33b4b5;
}
-/* line 693, jee.scss */
-#main #chapter-wrapper #node-8 h2.node-title {
- background: transparent url("../assets/img/title-JUSO-blur.png") no-repeat center center;
- background: none, url("../assets/img/title-JUSO-blur.svg") no-repeat center center;
+@media only screen and (max-width: 40em) {
+ /* line 800, jee.scss */
+ #main #chapter-wrapper #node-8 h2.node-title {
+ background: transparent url("../assets/img/title-JUSO-activ.png") no-repeat center center;
+ background: none, url("../assets/img/title-JUSO-activ.svg") no-repeat center center;
+ height: 3em;
+ }
}
-/* line 704, jee.scss */
+@media only screen and (min-width: 40.063em) {
+ /* line 806, jee.scss */
+ #main #chapter-wrapper #node-8 h2.node-title {
+ background: transparent url("../assets/img/title-JUSO-blur.png") no-repeat center center;
+ background: none, url("../assets/img/title-JUSO-blur.svg") no-repeat center center;
+ }
+}
+/* line 818, jee.scss */
#main #chapter-wrapper .node {
position: relative;
height: 100%;
width: 100%;
}
-/* line 707, jee.scss */
+/* line 821, jee.scss */
#main #chapter-wrapper .node a {
color: inherit;
}
-/* line 710, jee.scss */
+@media only screen and (max-width: 40em) {
+ /* line 818, jee.scss */
+ #main #chapter-wrapper .node {
+ overflow-y: auto;
+ }
+}
+/* line 828, jee.scss */
#main #chapter-wrapper .node-title {
font-family: "epflulb";
font-weight: normal;
text-transform: uppercase;
text-align: center;
line-height: 0.85;
- font-size: 2.268em;
- position: absolute;
- display: block;
- top: 0;
- left: 0;
- width: 100%;
- height: 100%;
- background-size: contain !important;
- text-indent: -5000px;
- z-index: -1;
- opacity: 0.4;
}
-/* line 726, jee.scss */
-#main #chapter-wrapper .node > .field, #main #chapter-wrapper .node > .block {
- position: absolute;
+@media only screen and (max-width: 40em) {
+ /* line 828, jee.scss */
+ #main #chapter-wrapper .node-title {
+ width: 80%;
+ margin: 2em auto 1em;
+ background-size: contain !important;
+ background-position: center center;
+ text-indent: -5000px;
+ }
}
-/* line 730, jee.scss */
+@media only screen and (min-width: 40.063em) {
+ /* line 828, jee.scss */
+ #main #chapter-wrapper .node-title {
+ font-size: 2.268em;
+ position: absolute;
+ display: block;
+ top: 0;
+ left: 0;
+ width: 100%;
+ height: 100%;
+ background-size: contain !important;
+ text-indent: -5000px;
+ z-index: -1;
+ opacity: 0.4;
+ }
+}
+@media only screen and (min-width: 40.063em) {
+ /* line 857, jee.scss */
+ #main #chapter-wrapper .node > .field, #main #chapter-wrapper .node > .block {
+ position: absolute;
+ }
+}
+/* line 862, jee.scss */
#main #chapter-wrapper .field-type-text-long, #main #chapter-wrapper .field-type-text {
background-color: rgba(255, 255, 255, 0.9);
min-height: 5em;
- width: 19em;
padding: 1em;
- z-index: 10;
- cursor: move;
}
-/* line 736, jee.scss */
+@media only screen and (max-width: 40em) {
+ /* line 862, jee.scss */
+ #main #chapter-wrapper .field-type-text-long, #main #chapter-wrapper .field-type-text {
+ width: 80%;
+ margin: 1em auto;
+ }
+}
+@media only screen and (min-width: 40.063em) {
+ /* line 862, jee.scss */
+ #main #chapter-wrapper .field-type-text-long, #main #chapter-wrapper .field-type-text {
+ width: 19em;
+ z-index: 10;
+ cursor: move;
+ }
+}
+/* line 877, jee.scss */
#main #chapter-wrapper .field-type-text-long .field-label, #main #chapter-wrapper .field-type-text .field-label {
text-transform: uppercase;
font-family: "epflulb";
font-size: 1.2em;
}
-/* line 742, jee.scss */
+/* line 883, jee.scss */
#main #chapter-wrapper .field-type-text-long h2, #main #chapter-wrapper .field-type-text h2 {
font-size: 0.80em;
}
-/* line 745, jee.scss */
+/* line 886, jee.scss */
#main #chapter-wrapper .field-type-text-long p, #main #chapter-wrapper .field-type-text p {
font-size: 0.80em;
margin-bottom: 0.5em;
}
-/* line 750, jee.scss */
+/* line 891, jee.scss */
#main #chapter-wrapper .field-type-text-long a, #main #chapter-wrapper .field-type-text a {
text-decoration: underline;
}
-/* line 754, jee.scss */
+/* line 896, jee.scss */
#main #chapter-wrapper .field-name-field-dbatre {
left: 60em;
}
-/* line 756, jee.scss */
+/* line 898, jee.scss */
#main #chapter-wrapper .field-name-field-dbatre ul {
margin: 1em 0 1em 1em;
}
-/* line 758, jee.scss */
+/* line 900, jee.scss */
#main #chapter-wrapper .field-name-field-dbatre ul li {
list-style: none;
line-height: 1;
@@ -4830,7 +5062,7 @@ div.messages {
position: relative;
font-size: 0.80em;
}
-/* line 764, jee.scss */
+/* line 906, jee.scss */
#main #chapter-wrapper .field-name-field-dbatre ul li:before {
content: "?";
position: absolute;
@@ -4838,14 +5070,14 @@ div.messages {
left: -1em;
font-family: "epflul";
}
-/* line 775, jee.scss */
+/* line 916, jee.scss */
#main #chapter-wrapper .field-name-field-partie {
height: 60%;
width: 100%;
top: 20%;
left: 0;
}
-/* line 778, jee.scss */
+/* line 920, jee.scss */
#main #chapter-wrapper .field-name-field-partie .field-items {
position: relative;
top: 0;
@@ -4853,12 +5085,12 @@ div.messages {
height: 100%;
width: auto;
}
-/* line 783, jee.scss */
+/* line 925, jee.scss */
#main #chapter-wrapper .field-name-field-partie .field-items .field {
position: relative;
display: inline-block;
}
-/* line 786, jee.scss */
+/* line 928, jee.scss */
#main #chapter-wrapper .field-name-field-partie .field-items .field .mask {
position: absolute;
width: 100%;
@@ -4875,15 +5107,9 @@ div.messages {
___/ // / / ___ |/ / _/ // /___ | |/ |/ / _, _/ ___ |/ ____/ ____/ /___/ _, _/
/____//_/ /_/ |_/_/ /___/\____/ |__/|__/_/ |_/_/ |_/_/ /_/ /_____/_/ |_|
*/
-/* line 807, jee.scss */
+/* line 949, jee.scss */
#static-wrapper {
position: absolute;
- top: 15%;
- bottom: 0;
- right: 20px;
- width: 80%;
- max-width: 55em;
- z-index: -1;
background-color: #fff;
opacity: 0;
-webkit-transition: 0.5s ease-out;
@@ -4891,33 +5117,80 @@ div.messages {
-webkit-transition-property: opacity;
transition-property: opacity;
}
-/* line 818, jee.scss */
+@media only screen and (max-width: 40em) {
+ /* line 949, jee.scss */
+ #static-wrapper {
+ top: 10%;
+ bottom: 0;
+ right: 0;
+ width: 100%;
+ z-index: -1;
+ }
+}
+@media only screen and (min-width: 40.063em) {
+ /* line 949, jee.scss */
+ #static-wrapper {
+ top: 15%;
+ bottom: 0;
+ right: 20px;
+ width: 80%;
+ max-width: 55em;
+ z-index: -1;
+ }
+}
+/* line 970, jee.scss */
#static-wrapper.visible {
opacity: 0.9;
-webkit-transition: 1.5s ease-out;
transition: 1.5s ease-out;
z-index: 500;
}
-/* line 824, jee.scss */
+/* line 976, jee.scss */
#static-wrapper > .close {
position: absolute;
- top: 20px;
- right: 20px;
- z-index: 500;
- width: 25px;
- height: 25px;
cursor: pointer;
background: transparent url("../assets/img/close.png") no-repeat center center;
background: none, url("../assets/img/close.svg") no-repeat center center;
}
-/* line 833, jee.scss */
-#static-wrapper > .inner {
- padding: 5em 7em;
- width: 100%;
- height: 100%;
- overflow: hidden;
+@media only screen and (max-width: 40em) {
+ /* line 976, jee.scss */
+ #static-wrapper > .close {
+ top: 10px;
+ right: 10px;
+ z-index: 500;
+ width: 15px;
+ height: 15px;
+ }
}
-/* line 837, jee.scss */
+@media only screen and (min-width: 40.063em) {
+ /* line 976, jee.scss */
+ #static-wrapper > .close {
+ top: 20px;
+ right: 20px;
+ z-index: 500;
+ width: 25px;
+ height: 25px;
+ }
+}
+@media only screen and (max-width: 40em) {
+ /* line 992, jee.scss */
+ #static-wrapper > .inner {
+ padding: 1em 1em 1.5em;
+ width: 100%;
+ height: 100%;
+ overflow: hidden;
+ }
+}
+@media only screen and (min-width: 40.063em) {
+ /* line 992, jee.scss */
+ #static-wrapper > .inner {
+ padding: 5em 7em;
+ width: 100%;
+ height: 100%;
+ overflow: hidden;
+ }
+}
+/* line 1002, jee.scss */
#static-wrapper > .inner > .node {
width: 100%;
height: 100%;
@@ -4925,42 +5198,42 @@ div.messages {
overflow-x: hidden;
padding-right: 1.5em;
}
-/* line 844, jee.scss */
+/* line 1009, jee.scss */
#static-wrapper h2.node-title {
font-family: "epflulb";
text-transform: uppercase !important;
font-size: 3em;
color: #000;
}
-/* line 852, jee.scss */
+/* line 1017, jee.scss */
#static-wrapper .content h3 {
font-family: "epflulb";
font-size: 2em;
text-transform: uppercase !important;
color: #8d198f;
}
-/* line 859, jee.scss */
+/* line 1024, jee.scss */
#static-wrapper .content h4 {
font-size: 1em;
font-weight: 700;
}
-/* line 866, jee.scss */
+/* line 1031, jee.scss */
#static-wrapper .content p {
font-family: "open_sans", sans-serif;
font-weight: 600;
font-size: 0.85em;
line-height: 1.5em;
}
-/* line 873, jee.scss */
+/* line 1038, jee.scss */
#static-wrapper .content a {
text-decoration: underline;
}
-/* line 876, jee.scss */
+/* line 1041, jee.scss */
#static-wrapper .content img.floatleft {
float: left;
margin-right: 1em;
}
-/* line 877, jee.scss */
+/* line 1042, jee.scss */
#static-wrapper .content img.floatright {
float: right;
margin-left: 1em;
@@ -4972,60 +5245,71 @@ div.messages {
/ __/ / /_/ / /_/ / / / / /___/ _, _/
/_/ \____/\____/ /_/ /_____/_/ |_|
*/
-/* line 889, jee.scss */
+/* line 1054, jee.scss */
#footer {
position: fixed;
bottom: 0;
right: 20px;
z-index: 900;
}
-/* line 894, jee.scss */
+/* line 1059, jee.scss */
body.chapter-displayed #footer {
display: none;
}
-/* line 898, jee.scss */
+/* line 1063, jee.scss */
#footer .block {
display: inline-block;
vertical-align: top;
font-size: 0.5em;
}
-/* line 902, jee.scss */
+/* line 1067, jee.scss */
#footer .block p {
font-size: inherit;
}
-/* line 903, jee.scss */
+/* line 1068, jee.scss */
#footer .block a {
color: #000;
}
-/* line 906, jee.scss */
+/* line 1071, jee.scss */
#footer .block-menu {
display: block;
font-size: inherit;
}
-/* line 909, jee.scss */
+/* line 1074, jee.scss */
#footer .block-menu ul {
margin: 0;
padding: 0;
}
-/* line 911, jee.scss */
+/* line 1076, jee.scss */
#footer .block-menu ul li {
- margin: 0 1em 0 0;
padding: 0;
display: inline-block;
list-style: none;
}
-/* line 915, jee.scss */
+@media only screen and (max-width: 40em) {
+ /* line 1076, jee.scss */
+ #footer .block-menu ul li {
+ margin: 0 0.5em 0.5em 0;
+ }
+}
+@media only screen and (min-width: 40.063em) {
+ /* line 1076, jee.scss */
+ #footer .block-menu ul li {
+ margin: 0 1em 0 0;
+ }
+}
+/* line 1086, jee.scss */
#footer .block-menu ul li a {
font-family: "epflulb";
color: #000;
text-transform: uppercase;
font-size: 0.6em;
}
-/* line 925, jee.scss */
+/* line 1096, jee.scss */
#footer p {
margin: 0;
}
-/* line 929, jee.scss */
+/* line 1100, jee.scss */
#footer #block-block-1 {
display: none;
}
@@ -5037,7 +5321,7 @@ body.chapter-displayed #footer {
/ / / // / ___/ / /___
/_/ /_/___//____/\____/
*/
-/* line 938, jee.scss */
+/* line 1109, jee.scss */
#loader {
position: absolute;
top: 50%;
@@ -5054,13 +5338,13 @@ body.chapter-displayed #footer {
-webkit-transition-property: opacity;
transition-property: opacity;
}
-/* line 949, jee.scss */
+/* line 1120, jee.scss */
body.loading #loader {
z-index: 1000;
opacity: 1;
}
-/* line 955, jee.scss */
+/* line 1126, jee.scss */
#fullscreen-btn {
position: fixed;
right: 20px;
@@ -5074,13 +5358,13 @@ body.loading #loader {
background: transparent url("../assets/img/fullscreen-on.png") no-repeat center center;
background: none, url("../assets/img/fullscreen-on.svg") no-repeat center center;
}
-/* line 964, jee.scss */
+/* line 1135, jee.scss */
.fullscreen #fullscreen-btn {
background: transparent url("../assets/img/fullscreen-off.png") no-repeat center center;
background: none, url("../assets/img/fullscreen-off.svg") no-repeat center center;
}
-/* line 977, jee.scss */
+/* line 1148, jee.scss */
.bubble-1 {
position: absolute;
z-index: 0;
@@ -5093,7 +5377,7 @@ body.loading #loader {
left: -200px;
}
-/* line 981, jee.scss */
+/* line 1152, jee.scss */
.bubble-2 {
position: absolute;
z-index: 0;
@@ -5106,7 +5390,7 @@ body.loading #loader {
right: -400px;
}
-/* line 986, jee.scss */
+/* line 1157, jee.scss */
.star {
position: absolute;
z-index: 0;
@@ -5119,7 +5403,7 @@ body.loading #loader {
}
/*Remove Mozilla Firefox Border – Remove Dotted Line Around Link */
-/* line 996, jee.scss */
+/* line 1167, jee.scss */
* {
outline: 0 !important;
}
@@ -5130,7 +5414,7 @@ body.loading #loader {
/ /_/ / /___/ /_/ / /_/ / /_/ /
/_____/_____/_____/\____/\____/
*/
-/* line 1005, jee.scss */
+/* line 1176, jee.scss */
#fps {
position: fixed;
bottom: 40px;
@@ -5138,7 +5422,7 @@ body.loading #loader {
z-index: 1000;
}
-/* line 1011, jee.scss */
+/* line 1182, jee.scss */
#nav-cursor {
position: absolute;
width: 6px;
diff --git a/sites/all/themes/gui/jee/css/jee.scss b/sites/all/themes/gui/jee/css/jee.scss
index 01803db..76bd3aa 100755
--- a/sites/all/themes/gui/jee/css/jee.scss
+++ b/sites/all/themes/gui/jee/css/jee.scss
@@ -35,6 +35,7 @@ $column-gutter: rem-calc(20);
background: transparent url('../assets/img/#{$img}.png') $r $x $y;
background: none, url('../assets/img/#{$img}.svg') $r $x $y;
}
+
/*
___ ____ ____
/ | / __ \/ __ \
@@ -44,8 +45,8 @@ $column-gutter: rem-calc(20);
*/
html{
position:relative;
- // overflow:hidden;
- // height:100%;
+ height:100%; width:100%;
+ overflow:hidden;
}
body{
@@ -113,11 +114,20 @@ $animeNodesDuration:3s;
z-index:0;
position:absolute;
overflow:hidden;
- width:700px;
- height:310px;
- top:50%; left:50%;
- margin-left:-350px;
- margin-top:-155px;
+ @media #{$small-only}{
+ width:200px;
+ height:88px;
+ top:50%; left:50%;
+ margin-left:-100px;
+ margin-top:-44px;
+ }
+ @media #{$medium-up} {
+ width:700px;
+ height:310px;
+ top:50%; left:50%;
+ margin-left:-350px;
+ margin-top:-155px;
+ }
// transition-property: "transform";
// transition-duration: 0.2s;
// transition-timing-function:ease-out;
@@ -138,12 +148,14 @@ $animeNodesDuration:3s;
}
&:before{
@include bg-svg-png('logo');
+ background-size: contain;
animation: introLogo $animeLogoDuration linear 0s;
animation-fill-mode: forwards;
}
&:after{
// background: transparent url('../assets/img/logo-blured.svg') no-repeat center center;
@include bg-svg-png('logo-blured');
+ background-size: contain;
animation: introLogoBlured $animeLogoDuration linear 0s;
animation-fill-mode: forwards;
}
@@ -152,6 +164,7 @@ $animeNodesDuration:3s;
h2{
// background: transparent url('../assets/img/slogan.svg') no-repeat center center;
@include bg-svg-png('slogan');
+ background-size: contain;
position:absolute;
width:100%; height:100%;
a{display:block;margin-top:-500%;}
@@ -188,6 +201,18 @@ div.messages{
| --| | | |__| | | -|__ | | __ -|_ _| | | | | | | | | __|
|_____|_____|_____|_____|__|__|_____| |_____| |_| |_|___|_____|____/|_____|
*/
+
+ @mixin title-size($w, $h) {
+ $factor: 0.5;
+ @media #{$small-only} {
+ width:$w*$factor; height:$h*$factor;
+ margin:0 $w*(1-$factor)*0.4;
+ }
+ @media #{$medium-up} {
+ width:$w; height:$h;
+ }
+ }
+
//SOL
#node-2{
&.node-teaser{
@@ -195,7 +220,11 @@ div.messages{
&, a{color:$SOL-col-txt;}
h2.node-title{
&,a{color:$SOL-color;}
- a{@include bg-svg-png('title-SOL'); width:170px; height:35px;}
+ a{
+ @include bg-svg-png('title-SOL');
+ @include title-size(170px, 35px);
+ background-size: contain;
+ }
}
.field-name-field-vignette{@include bg-svg-png('shadow-sol');}
.line{background-color:$SOL-col-active;}
@@ -214,7 +243,11 @@ div.messages{
&, a{color:$DPH-col-txt;}
h2.node-title{
&,a{color:$DPH-color;}
- a{@include bg-svg-png('title-DPH'); width:180px; height:80px;}
+ a{
+ @include bg-svg-png('title-DPH');
+ @include title-size(180px, 80px);
+ background-size: contain;
+ }
}
.field-name-field-vignette{@include bg-svg-png('shadow-dph');}
.line{background-color:$DPH-col-active;}
@@ -233,7 +266,11 @@ div.messages{
&, a{color:$SUB-col-txt;}
h2.node-title{
&,a{color:$SUB-color;}
- a{@include bg-svg-png('title-SUB'); width:200px; height:35px;}
+ a{
+ @include bg-svg-png('title-SUB');
+ @include title-size(200px, 35px);
+ background-size: contain;
+ }
}
.field-name-field-vignette{@include bg-svg-png('shadow-sub');}
.line{background-color:$SUB-col-active;}
@@ -252,7 +289,11 @@ div.messages{
&, a{color:$BC-col-txt;}
h2.node-title{
&,a{color:$BC-color;}
- a{@include bg-svg-png('title-BC'); width:120px; height:45px;}
+ a{
+ @include bg-svg-png('title-BC');
+ @include title-size(120px, 45px);
+ background-size: contain;
+ }
}
.field-name-field-vignette{@include bg-svg-png('shadow-bc');}
.line{background-color:$BC-col-active;}
@@ -271,7 +312,11 @@ div.messages{
&, a{color:$OPP-col-txt;}
h2.node-title{
&,a{color:$OPP-color;}
- a{@include bg-svg-png('title-OPP'); width:245px; height:95px;}
+ a{
+ @include bg-svg-png('title-OPP');
+ @include title-size(245px, 95px);
+ background-size: contain;
+ }
}
.field-name-field-vignette{@include bg-svg-png('shadow-opp');}
.line{background-color:$OPP-col-active;}
@@ -290,7 +335,11 @@ div.messages{
&, a{color:$DUB-col-txt;}
h2.node-title{
&,a{color:$DUB-color;}
- a{@include bg-svg-png('title-DUB'); width:195px; height:65px;}
+ a{
+ @include bg-svg-png('title-DUB');
+ @include title-size(195px, 65px);
+ background-size: contain;
+ }
}
.field-name-field-vignette{@include bg-svg-png('shadow-dub');}
.line{background-color:$DUB-col-active;}
@@ -309,7 +358,11 @@ div.messages{
&, a{color:$JUSO-col-txt;}
h2.node-title{
&,a{color:$JUSO-color;}
- a{@include bg-svg-png('title-JUSO'); width:200px; height:65px; }
+ a{
+ @include bg-svg-png('title-JUSO');
+ @include title-size(200px, 65px);
+ background-size: contain;
+ }
}
.field-name-field-vignette{@include bg-svg-png('shadow-juso');}
.line{background-color:$JUSO-col-active;}
@@ -369,7 +422,7 @@ div.messages{
z-index:5;
}
}
- >.content{position:relative;}
+ >.content{position:relative; left:0;}
.texts{
opacity:0; height:1px; overflow:hidden;
transition:1s ease-out;
@@ -533,7 +586,11 @@ div.messages{
}
}
- .field-name-field-partie{clear:both; padding-top:1em;}
+ .field-name-field-partie{clear:both;
+ @media #{$medium-up} {
+ padding-top:1em;
+ }
+ }
$shadow-size:3.5em;
@@ -591,6 +648,7 @@ div.messages{
position:absolute;
top:0; left:0;
width:100%; height:100%;
+ overflow:hidden;
z-index: -1;
opacity:0;
transition:2s ease-out;
@@ -624,7 +682,15 @@ div.messages{
.field-name-field-partager .field-label{
color:$SOL-col-active;
}
- h2.node-title{@include bg-svg-png('title-SOL-blur');}
+ @media #{$small-only} {
+ h2.node-title{
+ @include bg-svg-png('title-SOL-activ');
+ height:1.5em;
+ }
+ }
+ @media #{$medium-up} {
+ h2.node-title{@include bg-svg-png('title-SOL-blur');}
+ }
}
// DPH
#node-3{
@@ -635,7 +701,15 @@ div.messages{
.field-name-field-partager .field-label{
color:$DPH-col-active;
}
- h2.node-title{@include bg-svg-png('title-DPH-blur');}
+ @media #{$small-only} {
+ h2.node-title{
+ @include bg-svg-png('title-DPH-activ');
+ height:5em;
+ }
+ }
+ @media #{$medium-up} {
+ h2.node-title{@include bg-svg-png('title-DPH-blur');}
+ }
}
// SUB
#node-4{
@@ -646,7 +720,15 @@ div.messages{
.field-name-field-partager .field-label{
color:$SUB-col-active;
}
- h2.node-title{@include bg-svg-png('title-SUB-blur');}
+ @media #{$small-only} {
+ h2.node-title{
+ @include bg-svg-png('title-SUB-activ');
+ height:1.5em;
+ }
+ }
+ @media #{$medium-up} {
+ h2.node-title{@include bg-svg-png('title-SUB-blur');}
+ }
}
// BC
#node-5{
@@ -657,7 +739,15 @@ div.messages{
.field-name-field-partager .field-label{
color:$BC-col-active;
}
- h2.node-title{@include bg-svg-png('title-BC-blur');}
+ @media #{$small-only} {
+ h2.node-title{
+ @include bg-svg-png('title-BC-activ');
+ height:4em;
+ }
+ }
+ @media #{$medium-up} {
+ h2.node-title{@include bg-svg-png('title-BC-blur');}
+ }
}
// OPP
#node-6{
@@ -668,7 +758,15 @@ div.messages{
.field-name-field-partager .field-label{
color:$OPP-col-active;
}
- h2.node-title{@include bg-svg-png('title-OPP-blur');}
+ @media #{$small-only} {
+ h2.node-title{
+ @include bg-svg-png('title-OPP-activ');
+ height:6em;
+ }
+ }
+ @media #{$medium-up} {
+ h2.node-title{@include bg-svg-png('title-OPP-blur');}
+ }
}
// DUB
#node-7{
@@ -679,7 +777,15 @@ div.messages{
.field-name-field-partager .field-label{
color:$DUB-col-active;
}
- h2.node-title{@include bg-svg-png('title-DUB-blur');}
+ @media #{$small-only} {
+ h2.node-title{
+ @include bg-svg-png('title-DUB-activ');
+ height:5em;
+ }
+ }
+ @media #{$medium-up} {
+ h2.node-title{@include bg-svg-png('title-DUB-blur');}
+ }
}
// JUSO
#node-8{
@@ -690,7 +796,15 @@ div.messages{
.field-name-field-partager .field-label{
color:$JUSO-col-active;
}
- h2.node-title{@include bg-svg-png('title-JUSO-blur');}
+ @media #{$small-only} {
+ h2.node-title{
+ @include bg-svg-png('title-JUSO-activ');
+ height:3em;
+ }
+ }
+ @media #{$medium-up} {
+ h2.node-title{@include bg-svg-png('title-JUSO-blur');}
+ }
}
/*
@@ -705,6 +819,10 @@ div.messages{
position:relative;
height:100%; width:100%;
a{color:inherit;}
+
+ @media #{$small-only} {
+ overflow-y:auto;
+ }
}
.node-title{
@@ -714,24 +832,47 @@ div.messages{
text-align: center;
// max-width: 8.5em;
line-height: 0.85;
- font-size: 2.268em;
- position:absolute; display:block;
- top:0; left:0; width:100%; height:100%;
- background-size: contain!important;
- text-indent: -5000px;
- z-index:-1;
- opacity:0.4;
+
+ @media #{$small-only} {
+ width:80%;
+ margin:2em auto 1em;
+ background-size: contain!important;
+ background-position: center center;
+ text-indent: -5000px;
+ }
+
+ @media #{$medium-up} {
+ font-size: 2.268em;
+ position:absolute; display:block;
+ top:0; left:0; width:100%; height:100%;
+ background-size: contain!important;
+ text-indent: -5000px;
+ z-index:-1;
+ opacity:0.4;
+ }
+
}
- .node>.field, .node>.block{
- position:absolute;
+ @media #{$medium-up} {
+ .node>.field, .node>.block{
+ position:absolute;
+ }
}
.field-type-text-long, .field-type-text{
background-color: rgba(255,255,255,0.9);
- min-height:5em; width:19em; padding:1em;
- z-index:10;
- cursor:move;
+ min-height:5em; padding:1em;
+
+ @media #{$small-only} {
+ width:80%;
+ margin:1em auto;
+ }
+
+ @media #{$medium-up} {
+ width:19em;
+ z-index:10;
+ cursor:move;
+ }
.field-label{
text-transform: uppercase;
@@ -751,6 +892,7 @@ div.messages{
text-decoration: underline;
}
}
+
.field-name-field-dbatre{
left:60em;
ul{
@@ -771,8 +913,8 @@ div.messages{
}
}
-
.field-name-field-partie{
+ // position:absolute;
height:60%; width:100%;
top:20%; left:0;
.field-items{
@@ -806,9 +948,19 @@ div.messages{
*/
#static-wrapper{
position:absolute;
- top:15%; bottom:0; right:20px;
- width:80%; max-width:55em;
- z-index: -1;
+
+ @media #{$small-only} {
+ top:10%;
+ bottom:0; right:0;
+ width:100%;
+ z-index: -1;
+ }
+ @media #{$medium-up} {
+ top:15%; bottom:0; right:20px;
+ width:80%; max-width:55em;
+ z-index: -1;
+ }
+
background-color: #fff;
opacity:0;
@@ -823,16 +975,29 @@ div.messages{
>.close{
position:absolute;
- top:20px; right:20px;
- z-index: 500;
- width:25px; height:25px;
+ @media #{$small-only} {
+ top:10px; right:10px;
+ z-index: 500;
+ width:15px; height:15px;
+ }
+ @media #{$medium-up} {
+ top:20px; right:20px;
+ z-index: 500;
+ width:25px; height:25px;
+ }
cursor:pointer;
@include bg-svg-png('close');
}
>.inner{
- padding:5em 7em;
- width:100%; height:100%; overflow:hidden;
+ @media #{$small-only} {
+ padding:1em 1em 1.5em;
+ width:100%; height:100%; overflow:hidden;
+ }
+ @media #{$medium-up} {
+ padding:5em 7em;
+ width:100%; height:100%; overflow:hidden;
+ }
>.node{
width:100%; height:100%; overflow-y:auto; overflow-x:hidden;
@@ -909,7 +1074,13 @@ div.messages{
ul{
margin:0; padding:0;
li{
- margin:0 1em 0 0; padding:0;
+ @media #{$small-only} {
+ margin:0 0.5em 0.5em 0;
+ }
+ @media #{$medium-up} {
+ margin:0 1em 0 0;
+ }
+ padding:0;
display:inline-block;
list-style: none;
a{
diff --git a/sites/all/themes/gui/jee/js/jee.js b/sites/all/themes/gui/jee/js/jee.js
index ed10000..9a43dcf 100755
--- a/sites/all/themes/gui/jee/js/jee.js
+++ b/sites/all/themes/gui/jee/js/jee.js
@@ -22,6 +22,7 @@ jQuery(document).ready(function($) {
_$nav_cursor;
var _$body = $('body'),
+ _is_mobile = $('html').is('.mobile'),
_$header = $("#header"),
_$chapitres = $('.node-chapitre', '#main'),
_chapitres_len = _$chapitres.length,
@@ -484,8 +485,15 @@ jQuery(document).ready(function($) {
//http://technify.me/user-experience/javascript/jquery/trigger-custom-events-with-jquery/
// click to preview chapter
// $('h2.node-title, .field-name-field-partie:first>.field-name-field-vignette', this.$e)
+
this.$e
- .on('click',this.preview.bind(this))
+ .on('click', this, function(e){
+ if(_is_mobile){
+ e.data.loadNode(e);
+ }else{
+ e.data.preview(e);
+ }
+ });
// .on('click', this, function(e){
// // e.stopImmediatePropagation();
// console.log('click on chapter');
@@ -771,14 +779,16 @@ jQuery(document).ready(function($) {
console.log('Chapter :: displayNode '+this.nid);
// place text blocks
- this.texts_pos = shuffleArray([1,2,3,4]);
- this.$blocks
- .each(this.placeText.bind(this))
- .pep({
- allowDragEventPropagation:false,
- disableSelect:true,
- velocityMultiplier:1
- });
+ if(!_is_mobile){
+ this.texts_pos = shuffleArray([1,2,3,4]);
+ this.$blocks
+ .each(this.placeText.bind(this))
+ .pep({
+ allowDragEventPropagation:false,
+ disableSelect:true,
+ velocityMultiplier:1
+ });
+ }
// build video player
this.buildVideos();
@@ -846,10 +856,13 @@ jQuery(document).ready(function($) {
this.dimvideo.h = (this.dimvideo.w * parseInt($first_vid.attr("height")))/parseInt($first_vid.attr("width"));
}
- // redim each iframe to fit
+
// add a mask on top of each iframe to avoid bad interaction with vimeo
+ if(_is_mobile)
+ this.$vids.after('');
+
+ // redim each iframe to fit
this.$vids
- .after('')
.each(this.redimVideo.bind(this))
.each(this.setVidsEvents.bind(this));
diff --git a/sites/all/themes/gui/jee/preprocess/html.pre.php b/sites/all/themes/gui/jee/preprocess/html.pre.php
index 3ed773d..36bd2e9 100755
--- a/sites/all/themes/gui/jee/preprocess/html.pre.php
+++ b/sites/all/themes/gui/jee/preprocess/html.pre.php
@@ -31,7 +31,7 @@ $heads['viewport'] = array(
'#tag' => 'meta',
'#attributes' => array(
'name' => 'viewport',
- 'content' => 'width=device-width,initial-scale=1,maximum-scale=1',
+ 'content' => 'width=device-width,initial-scale=1,maximum-scale=1,user-scalable=no',
),
);
diff --git a/sites/all/themes/gui/jee/templates/html.tpl.php b/sites/all/themes/gui/jee/templates/html.tpl.php
index ce4732a..ff3968a 100755
--- a/sites/all/themes/gui/jee/templates/html.tpl.php
+++ b/sites/all/themes/gui/jee/templates/html.tpl.php
@@ -69,7 +69,8 @@
-
+
+
diff --git a/sites/all/themes/gui/jee/bower_components/modernizr/feature-detects/forms-validation.js b/sites/all/themes/gui/jee/bower_components/modernizr/feature-detects/forms-validation.js
index d52921a..5e5cfa6 100644
--- a/sites/all/themes/gui/jee/bower_components/modernizr/feature-detects/forms-validation.js
+++ b/sites/all/themes/gui/jee/bower_components/modernizr/feature-detects/forms-validation.js
@@ -7,56 +7,77 @@
(function(document, Modernizr){
- Modernizr.formvalidationapi = false;
- Modernizr.formvalidationmessage = false;
+Modernizr.formvalidationapi = false;
+Modernizr.formvalidationmessage = false;
- Modernizr.addTest('formvalidation', function() {
+Modernizr.addTest('formvalidation', function(){
var form = document.createElement('form');
- if ( !('checkValidity' in form) || !('addEventListener' in form) ) {
- return false;
+ if ( !('checkValidity' in form) ) {
+ return false;
}
- if ('reportValidity' in form) {
- return true;
- }
- var invalidFired = false;
- var input;
+ var body = document.body,
- Modernizr.formvalidationapi = true;
+ html = document.documentElement,
+
+ bodyFaked = false,
+
+ invaildFired = false,
+
+ input;
+
+ Modernizr.formvalidationapi = true;
// Prevent form from being submitted
- form.addEventListener('submit', function(e) {
- //Opera does not validate form, if submit is prevented
- if ( !window.opera ) {
- e.preventDefault();
- }
- e.stopPropagation();
- }, false);
+ form.onsubmit = function(e) {
+ //Opera does not validate form, if submit is prevented
+ if ( !window.opera ) {
+ e.preventDefault();
+ }
+ e.stopPropagation();
+ };
- // Calling form.submit() doesn't trigger interactive validation,
+ // Calling form.submit() doesn't trigger interactive validation,
// use a submit button instead
//older opera browsers need a name attribute
form.innerHTML = '';
- Modernizr.testStyles('#modernizr form{position:absolute;top:-99999em}', function( node ) {
- node.appendChild(form);
+ // FF4 doesn't trigger "invalid" event if form is not in the DOM tree
+ // Chrome throws error if invalid input is not visible when submitting
+ form.style.position = 'absolute';
+ form.style.top = '-99999em';
- input = form.getElementsByTagName('input')[0];
+ // We might in
in which case we need to create body manually
+ if ( !body ) {
+ bodyFaked = true;
+ body = document.createElement('body');
+ //avoid crashing IE8, if background image is used
+ body.style.background = "";
+ html.appendChild(body);
+ }
- // Record whether "invalid" event is fired
- input.addEventListener('invalid', function(e) {
- invalidFired = true;
+ body.appendChild(form);
+
+ input = form.getElementsByTagName('input')[0];
+
+ // Record whether "invalid" event is fired
+ input.oninvalid = function(e) {
+ invaildFired = true;
e.preventDefault();
e.stopPropagation();
- }, false);
+ };
- //Opera does not fully support the validationMessage property
- Modernizr.formvalidationmessage = !!input.validationMessage;
+ //Opera does not fully support the validationMessage property
+ Modernizr.formvalidationmessage = !!input.validationMessage;
- // Submit form by clicking submit button
- form.getElementsByTagName('button')[0].click();
- });
+ // Submit form by clicking submit button
+ form.getElementsByTagName('button')[0].click();
- return invalidFired;
- });
+ // Don't forget to clean up
+ body.removeChild(form);
+ bodyFaked && html.removeChild(body);
-})(document, window.Modernizr);
+ return invaildFired;
+});
+
+
+})(document, window.Modernizr);
\ No newline at end of file